#!/usr/bin/python
#
# CPUMon.py - A very lightweight CPU Temperature and Frequency
#             Monitoring desklet for adesklets.
# 
#  Copyright(C) 2008, Angelo arrifano <miknix@gmail.com>
#
#  NOTE: This desklet is getting information from:
#        CPU Freq - Linux cpufreq module
#        CPU Temp - AMD K8 sensor
#         
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

import adesklets
import os.path
from DigitalCommon import NumDisplay, WDDisplay

class CPUMon(adesklets.Events_handler):
	def __init__(self, basedir):
		if len(basedir) == 0:
			self.basedir = '.'
		else:
			self.basedir = basedir
		adesklets.Events_handler.__init__(self)

	def __del__(self):
		adesklets.Events_handler.__del__(self)

	def ready(self):
		# Setup window
		adesklets.window_resize(150, 24)
		adesklets.window_set_transparency(True)
		adesklets.window_show()

		# Draw background image
		imgBG = adesklets.load_image(os.path.join(self.basedir, "CPUMon.png"))
		adesklets.blend_image_onto_image(imgBG, 1, \
		                                 0, 0, 150, 24, \
		                                 0, 0, 150, 24)
		adesklets.free_image(imgBG)

		# Create three displays (temperature, frequency and watchdog)
		self.dispTemp = NumDisplay(32, 6)
		self.dispFreq = NumDisplay(73, 6)
		self.dispWD = WDDisplay(137, 16)

	def _display(self):
		# Read and display temperature
		# Information is read from AMD K8 Temperature sensor.
		f = open("/sys/devices/pci0000:00/0000:00:18.3/temp1_input", "r")
		val = str(int(f.readline()) / 1000).zfill(2)
		f.close()
		self.dispTemp.draw(val)

		# Read and display frequency
		# Information is read from CPU Frequency scaling with
		# on ondemand governor.
		f = open("/sys/devices/system/cpu/cpu0/cpufreq/scaling_cur_freq", "r")
		val = str(int(f.readline()) / 1000).zfill(4)
		f.close()
		self.dispFreq.draw(val)

		# Ping watchdog
		self.dispWD.ping()

	def alarm(self):
		self._display()
		return 2
        
CPUMon(os.path.dirname(__file__)).pause()
