#!/usr/bin/python
#
# GPUMon.py - A very lightweight nVidia GPU Temperature and Frequency
#             Monitoring desklet for adesklets.
# 
#  Copyright(C) 2008, Angelo arrifano <miknix@gmail.com>
#
#  NOTE: This desklet needs to import NVInfo which is also
#        distributed in this package. Please build NVInfo.so using
#        the provided Makefile before running this desklet.
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#

import adesklets
import NVInfo
import os.path
from DigitalCommon import NumDisplay, WDDisplay

class GPUMon(adesklets.Events_handler):
	def __init__(self, basedir):
		if len(basedir) == 0:
			self.basedir = '.'
		else:
			self.basedir = basedir
		adesklets.Events_handler.__init__(self)

	def __del__(self):
		adesklets.Events_handler.__del__(self)

	def ready(self):
		# Setup window
		adesklets.window_resize(150, 24)
		adesklets.window_set_transparency(True)
		adesklets.window_show()

		# Draw background image
		imgBG = adesklets.load_image(os.path.join(self.basedir, "GPUMon.png"))
		adesklets.blend_image_onto_image(imgBG, 1, \
		                                 0, 0, 150, 24, \
		                                 0, 0, 150, 24)
		adesklets.free_image(imgBG)

		# Create three displays (temperature, frequency and watchdog)
		self.dispTemp = NumDisplay(32, 6)
		self.dispFreq = NumDisplay(73, 6)
		self.dispWD = WDDisplay(137, 16)

	def _display(self):
		# Read and display temperature
		# Call NVInfo to get information from nvidia NVCtrl extension.
		val = str(NVInfo.Get_Temp()).zfill(2)
		self.dispTemp.draw(val)

		# Read and display frequency
		# Call NVInfo to get information from nvidia NVCtrl extension.
		# TODO: Also show mem clock?
		(gpu, mem) = NVInfo.Get_Freq()
		val = str(gpu).zfill(4)
		self.dispFreq.draw(val)

		# Ping watchdog
		self.dispWD.ping()

	def alarm(self):
		self._display()
		# Don't increase much the update interval, 
		# the NVCtrl protocol is a little CPU intensive.
		return 5
        
GPUMon(os.path.dirname(__file__)).pause()
